@@ -1,6 +1,6 @@
 use warnings;
 use strict;
-package Test::Module 0.001; # TRIAL
+package Test::Module 0.002; # TRIAL
 
 # ABSTRACT: brief summary of what this module is used for
 
@@ -9,12 +9,6 @@ our (@EXPORT_OK) = ();
 our (@EXPORT)    = (@EXPORT_OK);
 
 
-
-sub new {
-    my $pkg = shift;
-    bless {}, $pkg;
-}
-
 1;
 
 __END__
@@ -29,20 +23,13 @@ Test::Module - brief summary of what this module is used for
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
     use Test::Module;
 
-    my $obj = new Test::Module;
-    print "Hello World\n" if $obj->isa('Test::Modules');
-
-=head1 METHODS
-
-=head2 new
-
-Takes no arguments. Returns a blessed reference.
+    ## ... code that uses your package
 
 =head1 AUTHOR
 
